@@ -11,22 +11,22 @@
 #include "DNA_movieclip_types.h"
 #include "DNA_scene_types.h"
 
-#include "BLI_lasso_2d.h"
+#include "BLI_lasso_2d.hh"
 #include "BLI_listbase.h"
+#include "BLI_math_base.hh"
 #include "BLI_math_geom.h"
 #include "BLI_math_vector.h"
+#include "BLI_math_vector_types.hh"
 #include "BLI_rect.h"
 #include "BLI_utildefines.h"
 
-#include "BKE_context.h"
+#include "BKE_context.hh"
 #include "BKE_tracking.h"
 
 #include "WM_api.hh"
 #include "WM_types.hh"
 
 #include "ED_clip.hh"
-#include "ED_mask.hh"
-#include "ED_screen.hh"
 #include "ED_select_utils.hh"
 
 #include "RNA_access.hh"
@@ -36,8 +36,14 @@
 
 #include "DEG_depsgraph.hh"
 
-#include "clip_intern.h"         /* own include */
-#include "tracking_ops_intern.h" /* own include */
+#include "clip_intern.hh"         /* own include */
+#include "tracking_ops_intern.hh" /* own include */
+
+using blender::Array;
+using blender::int2;
+using blender::Span;
+
+namespace math = blender::math;
 
 /* -------------------------------------------------------------------- */
 /** \name Point track marker picking.
@@ -203,7 +209,8 @@ PointTrackPick ed_tracking_pick_point_track(const TrackPickOptions *options,
   MovieClip *clip = ED_space_clip_get_clip(space_clip);
   MovieTrackingObject *tracking_object = BKE_tracking_object_get_active(&clip->tracking);
 
-  const float distance_tolerance_px_squared = (12.0f * 12.0f) / space_clip->zoom;
+  const float distance_tolerance_px_squared = math::square(12.0f / space_clip->zoom *
+                                                           UI_SCALE_FAC);
   const bool are_disabled_markers_visible = (space_clip->flag & SC_HIDE_DISABLED) == 0;
   const int framenr = ED_space_clip_get_clip_frame_number(space_clip);
 
@@ -392,7 +399,8 @@ PlaneTrackPick ed_tracking_pick_plane_track(const TrackPickOptions *options,
   MovieTrackingObject *tracking_object = BKE_tracking_object_get_active(&clip->tracking);
   const int framenr = ED_space_clip_get_clip_frame_number(space_clip);
 
-  const float distance_tolerance_px_squared = (12.0f * 12.0f) / space_clip->zoom;
+  const float distance_tolerance_px_squared = math::square(12.0f / space_clip->zoom *
+                                                           UI_SCALE_FAC);
   PlaneTrackPick pick = plane_track_pick_make_null();
 
   LISTBASE_FOREACH (MovieTrackingPlaneTrack *, plane_track, &tracking_object->plane_tracks) {
@@ -569,8 +577,7 @@ static int select_exec(bContext *C, wmOperator *op)
    * operator can be used immediately after.
    * This logic makes it convenient to slide markers when left mouse selection is used. Without it
    * selection will be lost which causes inconvenience for the VFX artist. */
-  const bool activate_selected = !extend;
-  if (activate_selected && ed_tracking_pick_can_slide(sc, &pick)) {
+  if (!extend && ed_tracking_pick_can_slide(sc, &pick)) {
     if (pick.point_track_pick.track != nullptr) {
       tracking_object->active_track = pick.point_track_pick.track;
       tracking_object->active_plane_track = nullptr;
@@ -651,23 +658,6 @@ static int select_exec(bContext *C, wmOperator *op)
   WM_event_add_notifier(C, NC_GEOM | ND_SELECT, nullptr);
   DEG_id_tag_update(&clip->id, ID_RECALC_SELECT);
 
-  /* This is a bit implicit, but when the selection operator is used from a LMB Add Marker and
-   * tweak tool we do not want the pass-through here and only want selection to happen. This way
-   * the selection operator will not fall-through to Add Marker operator. */
-  if (activate_selected) {
-    if (ed_tracking_pick_can_slide(sc, &pick)) {
-      return OPERATOR_FINISHED | OPERATOR_PASS_THROUGH;
-    }
-
-    if (ed_tracking_pick_empty(&pick)) {
-      /* When nothing was selected pass-though and allow Add Marker part of the keymap to add new
-       * marker at the position. */
-      return OPERATOR_FINISHED | OPERATOR_PASS_THROUGH;
-    }
-
-    return OPERATOR_FINISHED;
-  }
-
   /* Pass-through + finished to allow tweak to transform. */
   return OPERATOR_FINISHED | OPERATOR_PASS_THROUGH;
 }
@@ -837,10 +827,7 @@ void CLIP_OT_select_box(wmOperatorType *ot)
 
 /********************** lasso select operator *********************/
 
-static int do_lasso_select_marker(bContext *C,
-                                  const int mcoords[][2],
-                                  const int mcoords_len,
-                                  bool select)
+static int do_lasso_select_marker(bContext *C, const Span<int2> mcoords, bool select)
 {
   SpaceClip *sc = CTX_wm_space_clip(C);
   ARegion *region = CTX_wm_region(C);
@@ -852,7 +839,7 @@ static int do_lasso_select_marker(bContext *C,
   const int framenr = ED_space_clip_get_clip_frame_number(sc);
 
   /* get rectangle from operator */
-  BLI_lasso_boundbox(&rect, mcoords, mcoords_len);
+  BLI_lasso_boundbox(&rect, mcoords);
 
   /* do actual selection */
   LISTBASE_FOREACH (MovieTrackingTrack *, track, &tracking_object->tracks) {
@@ -869,8 +856,7 @@ static int do_lasso_select_marker(bContext *C,
       ED_clip_point_stable_pos__reverse(sc, region, marker->pos, screen_co);
 
       if (BLI_rcti_isect_pt(&rect, screen_co[0], screen_co[1]) &&
-          BLI_lasso_is_point_inside(
-              mcoords, mcoords_len, screen_co[0], screen_co[1], V2D_IS_CLIPPED))
+          BLI_lasso_is_point_inside(mcoords, screen_co[0], screen_co[1], V2D_IS_CLIPPED))
       {
         if (select) {
           BKE_tracking_track_flag_set(track, TRACK_AREA_ALL, SELECT);
@@ -899,8 +885,7 @@ static int do_lasso_select_marker(bContext *C,
       ED_clip_point_stable_pos__reverse(sc, region, plane_marker->corners[i], screen_co);
 
       if (BLI_rcti_isect_pt(&rect, screen_co[0], screen_co[1]) &&
-          BLI_lasso_is_point_inside(
-              mcoords, mcoords_len, screen_co[0], screen_co[1], V2D_IS_CLIPPED))
+          BLI_lasso_is_point_inside(mcoords, screen_co[0], screen_co[1], V2D_IS_CLIPPED))
       {
         if (select) {
           plane_track->flag |= SELECT;
@@ -926,24 +911,22 @@ static int do_lasso_select_marker(bContext *C,
 
 static int clip_lasso_select_exec(bContext *C, wmOperator *op)
 {
-  int mcoords_len;
-  const int(*mcoords)[2] = WM_gesture_lasso_path_to_array(C, op, &mcoords_len);
+  const Array<int2> mcoords = WM_gesture_lasso_path_to_array(C, op);
 
-  if (mcoords) {
-    const eSelectOp sel_op = eSelectOp(RNA_enum_get(op->ptr, "mode"));
-    const bool select = (sel_op != SEL_OP_SUB);
-    if (SEL_OP_USE_PRE_DESELECT(sel_op)) {
-      SpaceClip *sc = CTX_wm_space_clip(C);
-      ED_clip_select_all(sc, SEL_DESELECT, nullptr);
-    }
-
-    do_lasso_select_marker(C, mcoords, mcoords_len, select);
-
-    MEM_freeN((void *)mcoords);
-
-    return OPERATOR_FINISHED;
+  if (mcoords.is_empty()) {
+    return OPERATOR_PASS_THROUGH;
   }
-  return OPERATOR_PASS_THROUGH;
+
+  const eSelectOp sel_op = eSelectOp(RNA_enum_get(op->ptr, "mode"));
+  const bool select = (sel_op != SEL_OP_SUB);
+  if (SEL_OP_USE_PRE_DESELECT(sel_op)) {
+    SpaceClip *sc = CTX_wm_space_clip(C);
+    ED_clip_select_all(sc, SEL_DESELECT, nullptr);
+  }
+
+  do_lasso_select_marker(C, mcoords, select);
+
+  return OPERATOR_FINISHED;
 }
 
 void CLIP_OT_select_lasso(wmOperatorType *ot)
